@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2016, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -31,23 +31,23 @@
     {
       _header= [[NSImageView alloc] initWithFrame:NSMakeRect(0, 0, NSWidth(frame), 23)];
       [self addSubview:_header];
-      [_header setAutoresizingMask:NSViewWidthSizable];
-      [_header setImageScaling:NSImageScaleAxesIndependently];
-      [_header setImage:[NSImage imageNamed:@"collapsing_panel_header_bg_flat.png"]];
+      _header.autoresizingMask = NSViewWidthSizable;
+      _header.imageScaling = NSImageScaleAxesIndependently;
+      _header.image = [NSImage imageNamed:@"collapsing_panel_header_bg_flat.png"];
   
       _toggleButton= [[NSButton alloc] initWithFrame:NSMakeRect(5, 5, 13, 13)];
-      [_toggleButton setBezelStyle:NSDisclosureBezelStyle];
+      _toggleButton.bezelStyle = NSDisclosureBezelStyle;
       [_toggleButton setButtonType:NSOnOffButton];
-      [_toggleButton setTitle:@""];
-      [_toggleButton setAction:@selector(toggle:)];
-      [_toggleButton setTarget:self];
-      [_toggleButton setState: NSOnState]; // expanded by default
+      _toggleButton.title = @"";
+      _toggleButton.action = @selector(toggle:);
+      _toggleButton.target = self;
+      _toggleButton.state = NSOnState; // expanded by default
       [self addSubview:_toggleButton];
     
       _label= [[NSTextField alloc] initWithFrame:NSMakeRect(20, 3, 20, 20)];
       [_label setBordered:NO];
       [_label setEditable:NO];
-      [_label setFont:[NSFont boldSystemFontOfSize:12]];
+      _label.font = [NSFont boldSystemFontOfSize:12];
       [_label setDrawsBackground:NO];
       [self addSubview:_label];
     }
@@ -88,14 +88,14 @@
 
 - (void)setExpanded:(BOOL)flag
 {
-  [_toggleButton setState:flag ? NSOnState : NSOffState];
+  _toggleButton.state = flag ? NSOnState : NSOffState;
   [self relayout];
 }
 
 
 - (void)setLabel:(NSString*)label
 {
-  [_label setStringValue:label];
+  _label.stringValue = label;
   [_label sizeToFit];
 }
 
@@ -116,8 +116,8 @@
                                              selector:@selector(contentFrameDidChange:)
                                                  name:NSViewFrameDidChangeNotification
                                                object:_content];
-    [subview setFrameOrigin:NSMakePoint(0, _header ? NSHeight([_header frame]) : 0)];
-    [subview setAutoresizingMask:NSViewWidthSizable|NSViewMaxYMargin];
+    [subview setFrameOrigin:NSMakePoint(0, _header ? NSHeight(_header.frame) : 0)];
+    subview.autoresizingMask = NSViewWidthSizable|NSViewMaxYMargin;
     [self relayout];
   }
 }
@@ -150,17 +150,17 @@
 
 - (void)relayout
 {
-  NSRect contentRect= [_content frame];
+  NSRect contentRect= _content.frame;
   NSRect newContentRect;
   NSRect buttonRect;
-  NSRect rect= [self frame];
-  CGFloat headerHeight= _header ? NSHeight([_header frame]) : 0;
+  NSRect rect= self.frame;
+  CGFloat headerHeight= _header ? NSHeight(_header.frame) : 0;
   
   if (_relayouting)
     return;
   _relayouting= YES;
   
-  if (!_toggleButton || [_toggleButton state] == NSOnState)
+  if (!_toggleButton || _toggleButton.state == NSOnState)
   {
     rect.size.height= headerHeight + NSHeight(contentRect);
 
@@ -173,23 +173,23 @@
     [_content setHidden:YES];
   }
   
-  buttonRect.origin.x= rect.size.width - [_buttons count] * headerHeight;
+  buttonRect.origin.x= rect.size.width - _buttons.count * headerHeight;
   buttonRect.origin.y= 0;
   buttonRect.size.width= headerHeight;
   buttonRect.size.height= headerHeight;
   for (NSButton *btn in _buttons)
   {
-    [btn setFrame:buttonRect];
+    btn.frame = buttonRect;
     buttonRect.origin.x+= headerHeight;
   }
   
   newContentRect= NSMakeRect(0, headerHeight, NSWidth(rect), NSHeight(contentRect));
   
   if (!NSEqualRects(newContentRect, contentRect))
-    [_content setFrame:newContentRect];
+    _content.frame = newContentRect;
   
-  if (!NSEqualRects([self frame], rect))
-    [self setFrame:rect];
+  if (!NSEqualRects(self.frame, rect))
+    self.frame = rect;
   
   _relayouting= NO;
 }
@@ -199,7 +199,7 @@
             withAction: (SEL)selector
                 target: (id)target
 {
-  CGFloat headerHeight= NSHeight([_header frame]);
+  CGFloat headerHeight= NSHeight(_header.frame);
   NSButton *button = [[NSButton alloc] initWithFrame: NSMakeRect(0, 0, headerHeight, headerHeight)];
 
   _initializing= YES;
@@ -207,11 +207,11 @@
   [_buttons addObject:button];
   
   [button setBordered:NO];
-  [button setImage:icon];
-  [button setImagePosition:NSImageOnly];
-  [button setAction:selector];
-  [button setTarget:target];
-  [button setEnabled: (selector != nil) && (target != nil)];
+  button.image = icon;
+  button.imagePosition = NSImageOnly;
+  button.action = selector;
+  button.target = target;
+  button.enabled = (selector != nil) && (target != nil);
   
   [self addSubview:button];
   
