@@ -2,17 +2,9 @@
  Copyright 2009 Sun Microsystems, Inc.
  */
 
-
-
 #import <SenTestingKit/SenTestingKit.h>
 
-
-
-@interface WBColorCellUnitTests : SenTestCase
-{
-  
+@interface WBColorCellUnitTests : SenTestCase {
 }
 
 @end
-
-
