@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009, 2016, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -19,12 +19,7 @@
 
 #import "WBTabView.h"
 
-@interface WBEditorTabView : WBTabView
-{
-
+@interface WBEditorTabView : WBTabView {
 }
 
-
 @end
-
-
