@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009, 2016, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -19,15 +19,9 @@
 
 #import "WBTabItem.h"
 
-@interface WBPaletteTabItem : WBTabItem
-{
+@interface WBPaletteTabItem : WBTabItem {
 }
 
-
-+ (WBTabItem*) tabItemWithIdentifier: (id) identifier
-							   label: (NSString*) label;
-
++ (WBTabItem*)tabItemWithIdentifier:(id)identifier label:(NSString*)label;
 
 @end
-
-
