@@ -1,38 +1,34 @@
-/* 
- * Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
+/*
+ * Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; version 2 of the
  * License.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301  USA
  */
 
-
 #import <Cocoa/Cocoa.h>
 #include "grts/structs.ui.h"
 
-namespace grt
-{
+namespace grt {
   class BaseListRef;
   class Module;
 }
-namespace bec
-{
+namespace bec {
   class GRTManager;
   class BaseEditor;
 }
-namespace mforms
-{
+namespace mforms {
   class DockingPoint;
 }
 
@@ -40,7 +36,6 @@ namespace mforms
 //! in dockableView.
 @interface WBPluginEditorBase : NSViewController {
   NSSize mMinumumSize;
-  bec::GRTManager *_grtm; // Must be assigned by subclasses.
 
   mforms::DockingPoint *mDockingPoint;
   ui_ObjectEditorRef mEditorGRTObject;
@@ -49,22 +44,21 @@ namespace mforms
   IBOutlet __weak NSButton *mRevertButton;
 }
 
-@property (readonly) BOOL enableLiveChangeButtons;
-@property  NSSize minimumSize;
-@property (readonly) bec::BaseEditor *editorBE;
-@property (readonly) bec::GRTManager *grtManager;
-@property (readonly, strong) id identifier;
-@property (readonly, copy) NSImage *titleIcon;
+@property(readonly) BOOL enableLiveChangeButtons;
+@property NSSize minimumSize;
+@property(readonly) bec::BaseEditor *editorBE;
+@property(readonly, strong) id identifier;
+@property(readonly, copy) NSImage *titleIcon;
 
-- (void)updateTitle:(NSString*)title;
+- (void)updateTitle:(NSString *)title;
 
-- (void)reinitWithArguments:(const grt::BaseListRef&)args;
+- (void)reinitWithArguments:(const grt::BaseListRef &)args;
 - (void)notifyObjectSwitched;
 
 - (void)refresh;
 
 - (void)setCompactMode:(BOOL)flag;
-- (BOOL)matchesIdentifierForClosingEditor:(NSString*)identifier;
+- (BOOL)matchesIdentifierForClosingEditor:(NSString *)identifier;
 
 - (void)pluginDidShow:(id)sender;
 - (BOOL)pluginWillClose:(id)sender;
@@ -72,9 +66,8 @@ namespace mforms
 - (void)applyLiveChanges:(id)sender;
 - (void)revertLiveChanges:(id)sender;
 
-- (void)setupEditorOnHost: (NSView*)host;
+- (void)setupEditorOnHost:(NSView *)host;
 
-
-- (void)enablePluginDocking:(NSTabView*)tabView;
+- (void)enablePluginDocking:(NSTabView *)tabView;
 
 @end
