@@ -1,29 +1,27 @@
-/* 
- * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
+/*
+ * Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; version 2 of the
  * License.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301  USA
  */
 
-namespace grt
-{
+namespace grt {
   class BaseListRef;
   class Module;
 }
-namespace bec
-{
+namespace bec {
   class GRTManager;
 }
 
@@ -31,9 +29,7 @@ namespace bec
 // TODO: convert to protocol.
 @interface WBPluginWindowBase : NSObject
 
-- (instancetype)initWithModule: (grt::Module *)module
-                    grtManager: (bec::GRTManager *)grtm
-                     arguments: (const grt::BaseListRef &)args;
+- (instancetype)initWithModule:(grt::Module *)module arguments:(const grt::BaseListRef &)args NS_DESIGNATED_INITIALIZER;
 
 - (void)showModal;
 
