@@ -1,6 +1,6 @@
-/* 
- * Copyright (c) 2009, 2016, Oracle and/or its affiliates. All rights reserved.
- * 
+/*
+ * Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; version 2 of the License.
@@ -14,13 +14,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
 
-namespace bec
-{
+namespace bec {
   class UIForm;
 };
 
-namespace wb
-{
+namespace wb {
   class WBContextUI;
   class WBContext;
   struct WBOptions;
@@ -29,12 +27,12 @@ namespace wb
 @class MainWindowController;
 @class WBBasePanel;
 
-typedef WBBasePanel *(*FormPanelFactory)(MainWindowController *controller, boost::shared_ptr<bec::UIForm> form);
+typedef WBBasePanel *(*FormPanelFactory)(MainWindowController *controller, std::shared_ptr<bec::UIForm> form);
 
 // TODO: merge this class with MainWindowController. It makes no sense to have 2 controller classes.
-@interface WBMainController : NSObject <NSApplicationDelegate, NSFileManagerDelegate>
+@interface WBMainController : NSObject<NSApplicationDelegate, NSFileManagerDelegate>
 
-- (void)registerFormPanelFactory: (FormPanelFactory)fac forFormType: (const std::string&)type;
+- (void)registerFormPanelFactory:(FormPanelFactory)fac forFormType:(const std::string &)type;
 
 - (IBAction)menuItemClicked:(id)sender;
 - (IBAction)showDiagramProperties:(id)sender;
@@ -43,6 +41,6 @@ typedef WBBasePanel *(*FormPanelFactory)(MainWindowController *controller, boost
 - (IBAction)buttonClicked:(id)sender;
 
 - (IBAction)inputDialogClose:(id)sender;
-- (void) showPageSetup: (id)sender;
+- (void)showPageSetup:(id)sender;
 
 @end
