@@ -1,6 +1,6 @@
-/* 
- * Copyright (c) 2010, 2015, Oracle and/or its affiliates. All rights reserved.
- * 
+/*
+ * Copyright (c) 2010, 2017, Oracle and/or its affiliates. All rights reserved.
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; version 2 of the License.
@@ -21,11 +21,11 @@
 
 @interface WBModelOverviewPanel : WBSplitPanel
 
-- (instancetype)initWithWBContextUI: (wb::WBContextUI *)wbui NS_DESIGNATED_INITIALIZER;
+- (instancetype)init NS_DESIGNATED_INITIALIZER;
 
-@property (readonly, copy) NSString *identifier;
-@property (weak, readonly) WBOverviewPanel *overview;
-@property (weak, readonly) WBModelSidebarController *sidebarController;
+@property(readonly, copy) NSString *identifier;
+@property(weak, readonly) WBOverviewPanel *overview;
+@property(weak, readonly) WBModelSidebarController *sidebarController;
 
 - (void)selectionChanged;
 
