@@ -1,16 +1,16 @@
-/* 
- * Copyright (c) 2013, 2014, Oracle and/or its affiliates. All rights reserved.
+/*
+ * Copyright (c) 2013, 2017, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; version 2 of the
  * License.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
@@ -20,15 +20,16 @@
 #pragma once
 
 #ifdef _WIN64
-  typedef __int64 ssize_t;
+typedef __int64 ssize_t;
 #else
-  typedef int ssize_t;
+typedef int ssize_t;
 #endif
 
 #define WIN32_LEAN_AND_MEAN
 #define NOMINMAX
 
 #include <windows.h>
+#include <shellapi.h>
 
 #include <stdexcept>
 #include <functional>
@@ -41,11 +42,29 @@
 #include <wchar.h>
 #include <codecvt>
 #include <fcntl.h>
+#include <fstream>
+#include <sstream>
+#include <unordered_set>
+#include <list>
+#include <inttypes.h>
+#include <string>
+#include <map>
+#include <vector>
+#include <sstream>
+#include <sddl.h>
+#include <stdio.h>
+#include <winevt.h>
+#include <iterator>
+#include <cctype>
+#include <memory>
 
 #include <VersionHelpers.h>
 
-#include <boost/function.hpp>
-#include <boost/bind.hpp>
+#include <boost/locale/encoding_utf.hpp>
+#include <boost/optional.hpp>
+#include <boost/cstdint.hpp>
 
 #include <glib/glib.h>
 #include <glib/gstdio.h>
+#include <iosfwd>
+#include <fstream>
