@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2016, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,34 +21,39 @@
 #import "MFMForms.h"
 #include "base/string_utilities.h"
 
-#import "MFContainerBase.h" // to get forw declaration of setFreezeRelayout:
+#import "MFContainerBase.h" // to get forward declaration of setFreezeRelayout:
 #import "ScintillaView.h"    // For drop delegate retrieval.
 #import "NSColor_extras.h"
 
-enum ViewFlags
-{
-  WidthFixedFlag = (1<<8),
-  HeightFixedFlag = (1<<9),
-  ViewFlagsMask = (WidthFixedFlag|HeightFixedFlag)
-};
-
 @implementation NSView(MForms)
 
-
 - (id)innerView
 {
   return self;
 }
 
-static const char *viewFlagsKey = "viewFlagsKey";
+static const char *minimumSizeKey = "minimumSizeKey";
 
-- (NSInteger)viewFlags
+- (NSSize)minimumSize
 {
-  NSNumber *value = objc_getAssociatedObject(self, viewFlagsKey);
-  return value.intValue;
+  NSValue *value = objc_getAssociatedObject(self, minimumSizeKey);
+  return value.sizeValue;
 }
 
-- (void)setViewFlags: (NSInteger)value
+- (void)setMinimumSize: (NSSize)size
+{
+  objc_setAssociatedObject(self, minimumSizeKey, [NSValue valueWithSize: size], OBJC_ASSOCIATION_RETAIN);
+}
+
+static const char *viewFlagsKey = "viewFlagsKey";
+
+- (ViewFlags)viewFlags
+{
+  NSNumber *value = objc_getAssociatedObject(self, viewFlagsKey);
+  return (ViewFlags)value.intValue;
+}
+
+- (void)setViewFlags: (ViewFlags)value
 {
   objc_setAssociatedObject(self, viewFlagsKey, @(value), OBJC_ASSOCIATION_RETAIN);
 }
@@ -125,10 +130,10 @@ static const char *lastDropPositionKey = "lastDropPositionKey";
 
 - (bool)handleMouseUp: (NSEvent*)event owner: (mforms::View *)mOwner
 {
-  NSPoint p = [self convertPoint: [event locationInWindow] fromView: nil];
+  NSPoint p = [self convertPoint: event.locationInWindow fromView: nil];
 
   mforms::MouseButton mouseButton;
-  switch ([event buttonNumber]) // NSLeftMouseDown etc are NOT buttonNumber constants
+  switch (event.buttonNumber) // NSLeftMouseDown etc are NOT buttonNumber constants
   {
     case 1:
       mouseButton = mforms::MouseButtonRight;
@@ -144,7 +149,7 @@ static const char *lastDropPositionKey = "lastDropPositionKey";
   }
 
   bool handled = false;
-  switch ([event clickCount])
+  switch (event.clickCount)
   {
     case 1:
       handled = mOwner->mouse_click(mouseButton, p.x, p.y);
@@ -163,9 +168,9 @@ static const char *lastDropPositionKey = "lastDropPositionKey";
 
 - (bool)handleMouseDown: (NSEvent*)event owner: (mforms::View *)mOwner
 {
-  NSPoint p = [self convertPoint: [event locationInWindow] fromView: nil];
+  NSPoint p = [self convertPoint: event.locationInWindow fromView: nil];
   mforms::MouseButton mouseButton;
-  switch ([event buttonNumber]) // NSLeftMouseDown etc are NOT buttonNumber constants
+  switch (event.buttonNumber) // NSLeftMouseDown etc are NOT buttonNumber constants
   {
     case 1:
       mouseButton = mforms::MouseButtonRight;
@@ -190,7 +195,7 @@ static const char *lastDropPositionKey = "lastDropPositionKey";
   // We have to map mouseDragged to mouseMoved as other platforms don't do this separation.
   // However the mouse button recorded in the event for mouseMoved is that of the last pressed
   // (and released) button. A currently pressed button produces mouseDragged instead.
-  NSPoint p = [self convertPoint: [event locationInWindow] fromView: nil];
+  NSPoint p = [self convertPoint: event.locationInWindow fromView: nil];
 
   mforms::MouseButton mouseButton;
   if (event.type == NSLeftMouseDragged)
@@ -232,7 +237,7 @@ static const char *lastDropPositionKey = "lastDropPositionKey";
 
   NSTrackingAreaOptions options = NSTrackingMouseEnteredAndExited | NSTrackingMouseMoved |
     NSTrackingActiveInActiveApp | NSTrackingInVisibleRect;
-  currentArea = [[NSTrackingArea alloc] initWithRect: [self bounds] options: options owner: self userInfo: nil];
+  currentArea = [[NSTrackingArea alloc] initWithRect: self.bounds options: options owner: self userInfo: nil];
   [self addTrackingArea: currentArea];
 
   return currentArea;
@@ -240,103 +245,22 @@ static const char *lastDropPositionKey = "lastDropPositionKey";
 
 //--------------------------------------------------------------------------------------------------
 
-- (void)setFixedFrameSize: (NSSize)size
+/**
+ * Returns the view's preferred size. Since a raw view doesn't know anything about its content
+ * the prefered size is its minimum size or the proposal (whichever is larger). Descendants (like container classes)
+ * override this and compute their real preferred size.
+ */
+- (NSSize)preferredSize: (NSSize)proposal
 {
-  NSRect frame = [self frame];
-  NSUInteger flags = self.viewFlags & ~ViewFlagsMask;
-
-  if (size.width > 0)
-  {
-    frame.size.width= size.width;
-    flags|= WidthFixedFlag;
-  }
-  if (size.height > 0)
-  {
-    frame.size.height= size.height;
-    flags|= HeightFixedFlag; //That flags leads to problems in layouting as then always
-                               // the current frame size is used, instead of the min/preferred size.
-  }
-  
-  self.viewFlags = flags;
-  [self setFrame: frame];
+  return { MAX(self.minimumSize.width, proposal.width), MAX(self.minimumSize.height, proposal.height) };
 }
 
-
-- (BOOL)widthIsFixed
+- (void)relayout
 {
-  return (self.viewFlags & WidthFixedFlag) != 0;
+  [self resizeSubviewsWithOldSize: self.frame.size];
 }
 
-- (BOOL)heightIsFixed
-{
-  return (self.viewFlags & HeightFixedFlag) != 0;
-}
-
-- (NSSize)minimumSize
-{
-  return NSMakeSize(0, 0);
-}
-
-- (NSSize)fixedFrameSize
-{
-  return [self frame].size;
-}
-
-- (NSSize)preferredSize
-{
-  NSSize size= [self minimumSize];
-
-  // The preferred size is actually about what would be needed to fit everything nicely
-  //   not what is the current size of the control. The latter approach messes up the layouting
-  //   where the fixed size is considered anyway.
-  NSSize fsize = [self fixedFrameSize];
-
-  // If a fixed size is set honour that but don't go below the
-  // minimal required size.
-  if ([self widthIsFixed])
-    size.width= MAX(size.width, fsize.width);
-  if ([self heightIsFixed])
-    ; //size.height= MAX(size.height, fsize.height); see comment above
-
-  return size;
-}
-
-
-- (NSSize)preferredSizeForWidth: (float)width
-{
-  NSSize size= [self minimumSizeForWidth: [self widthIsFixed] ? NSWidth([self frame]) : width];
-  
-  if ([self heightIsFixed])
-    size.height= [self fixedFrameSize].height;
-  if ([self widthIsFixed])
-    size.width= [self fixedFrameSize].width;
-  
-  return size;  
-}
-
-
-- (NSSize)minimumSizeForWidth:(float)width
-{
-  return [self minimumSize];
-}
-
-
-- (void)subviewMinimumSizeChanged
-{
-  if ([[self window] respondsToSelector:@selector(subviewMinimumSizeChanged)])
-  {
-    // assume this is the toplevel view so just forward to the window
-    [(id)[self window] subviewMinimumSizeChanged];
-  }
-  else
-  {
-    for (id subview in [self subviews])
-      [subview resizeSubviewsWithOldSize: NSMakeSize(0, 0)];
-  }
-}
-
-
-- (void)drawBounds:(NSRect)rect
+- (void)drawBounds: (NSRect)rect
 {
   NSFrameRect(rect);
   [NSBezierPath strokeLineFromPoint:NSMakePoint(NSMinX(rect), NSMinY(rect))
@@ -376,9 +300,9 @@ struct PasteboardDataWrapper {
   if (delegate == NULL)
   {
     if ([self isKindOfClass: [SCIContentView class]])
-      delegate = [(SCIContentView *)self owner].dropDelegate;
+      delegate = ((SCIContentView *)self).owner.dropDelegate;
     if (delegate == NULL && [self respondsToSelector: @selector(mformsObject)])
-      delegate = dynamic_cast<mforms::DropDelegate*>([self mformsObject]);
+      delegate = dynamic_cast<mforms::DropDelegate*>(self.mformsObject);
   }
   return delegate;
 }
@@ -415,7 +339,7 @@ struct PasteboardDataWrapper {
       if ([entry isEqualToString: NSFilenamesPboardType])
         formats.push_back(mforms::DragFormatFileName);
       else
-        formats.push_back([entry UTF8String]);
+        formats.push_back(entry.UTF8String);
   }
 
   NSDragOperation result = NSDragOperationNone;
@@ -459,7 +383,7 @@ struct PasteboardDataWrapper {
     {
       NSString *text = [pasteboard stringForType: NSStringPboardType];
       if (delegate->text_dropped(view, base::Point(location.x, location.y), operations,
-                                 [text UTF8String]) != mforms::DragOperationNone)
+                                 text.UTF8String) != mforms::DragOperationNone)
         return YES;
     }
     else
@@ -468,7 +392,7 @@ struct PasteboardDataWrapper {
         NSArray *fileNames = [pasteboard propertyListForType: NSFilenamesPboardType];
         std::vector<std::string> names;
         for (NSString *name in fileNames)
-          names.push_back([name UTF8String]);
+          names.push_back(name.UTF8String);
         if (names.size() > 0 && delegate->files_dropped(view, base::Point(location.x, location.y),
                                                         operations, names) != mforms::DragOperationNone)
           return YES;
@@ -480,7 +404,7 @@ struct PasteboardDataWrapper {
         if (data != NULL)
         {
           if (delegate->data_dropped(view, base::Point(location.x, location.y), operations, data,
-                                     [entry UTF8String]) != mforms::DragOperationNone)
+                                     entry.UTF8String) != mforms::DragOperationNone)
             return YES;
         }
       }
@@ -695,6 +619,26 @@ sourceOperationMaskForDraggingContext: (NSDraggingContext)context;
       return nativeOperations;
   }
 }
+
+- (mforms::ModifierKey) modifiersFromEvent: (NSEvent*) event
+{
+  NSUInteger modifiers = event.modifierFlags;
+  mforms::ModifierKey mforms_modifiers = mforms::ModifierNoModifier;
+
+  if ((modifiers & NSControlKeyMask) != 0)
+    mforms_modifiers = mforms::ModifierKey(mforms_modifiers | mforms::ModifierControl);
+  if ((modifiers & NSShiftKeyMask) != 0)
+    mforms_modifiers = mforms::ModifierKey(mforms_modifiers | mforms::ModifierShift);
+  if ((modifiers & NSCommandKeyMask) != 0)
+    mforms_modifiers = mforms::ModifierKey(mforms_modifiers | mforms::ModifierCommand);
+  if ((modifiers & NSAlternateKeyMask) != 0)
+    mforms_modifiers = mforms::ModifierKey(mforms_modifiers | mforms::ModifierAlt);
+
+  return mforms_modifiers;
+}
+
+//--------------------------------------------------------------------------------------------------
+
 @end
 
 //--------------------------------------------------------------------------------------------------
@@ -749,8 +693,10 @@ NSView *nsviewForView(mforms::View *view)
 static void view_destroy(::mforms::View *self)
 {
   id view = self->get_data();
-  if (view && [view respondsToSelector: @selector(destroy)])
-    [view performSelector: @selector(destroy)];
+  SEL selector = NSSelectorFromString(@"destroy");
+  if (view && [view respondsToSelector: selector])
+    ((void (*)(id, SEL))[view methodForSelector: selector])(view, selector);
+
   if ([view respondsToSelector: @selector(superview)] && [view superview])
     [view removeFromSuperview];
 }
@@ -762,7 +708,7 @@ static int view_get_x(::mforms::View *self)
   if (view)
   {
     NSView* widget = view;
-    return NSMinX([widget frame]);
+    return NSMinX(widget.frame);
   }
   return 0;
 }
@@ -773,27 +719,77 @@ static int view_get_y(::mforms::View *self)
   if (view)
   {
     NSView* widget = view;
-    return NSMinY([widget frame]);
+    return NSMinY(widget.frame);
   }
   return 0;
 }
 
 static void view_set_size(::mforms::View *self, int w, int h)
 {
-  id view = self->get_data();
-  if (view != nil && [view respondsToSelector: @selector(setFixedFrameSize:)])
-  {
-    [view setFixedFrameSize: NSMakeSize(w,h)];
+  id frontend = self->get_data();
+  if ([frontend isKindOfClass: NSView.class]) {
+    NSView *view = frontend;
+    NSSize size = { (CGFloat)w, (CGFloat)h };
+    if (w < 0)
+      size.width = view.frame.size.width;
+    if (h < 0)
+      size.height = view.frame.size.height;
+    view.frameSize = size;
+    if (w < 0)
+      size.width = 0;
+    if (h < 0)
+      size.height = 0;
+    view.minimumSize = size;
+  } else {
+      // Window controller/window/panel.
+      NSWindow *window;
+      if ([frontend isKindOfClass: NSWindowController.class])
+          window = [frontend window];
+      else
+          window = frontend;
+
+    NSRect frame = window.frame;
+    if (w >= 0)
+      frame.size.width = w;
+    if (h >= 0)
+      frame.size.height = h;
+    [window setFrame: frame display: YES animate: NO];
+    window.minSize = frame.size;
+  }
+}
+
+static void view_set_min_size(::mforms::View *self, int w, int h)
+{
+  id frontend = self->get_data();
+  if ([frontend isKindOfClass: NSView.class]) {
+    NSView *view = frontend;
+    NSSize size = { (CGFloat)w, (CGFloat)h };
+    if (w < 0)
+      size.width = 0;
+    if (h < 0)
+      size.height = 0;
+    view.minimumSize = size;
+  } else {
+      // Window controller/window/panel.
+      NSWindow *window;
+      if ([frontend isKindOfClass: NSWindowController.class])
+          window = [frontend window];
+      else
+          window = frontend;
+
+    NSRect frame = window.frame;
+    if (w >= 0)
+      frame.size.width = w;
+    if (h >= 0)
+      frame.size.height = h;
+    window.minSize = frame.size;
   }
 }
 
 static void view_set_position(::mforms::View *self, int x, int y)
 {
-  id view = self->get_data();
-  if (view)
-  {
-    [view setFrameOrigin: NSMakePoint(x, y)];
-  }
+  NSView *view = self->get_data();
+  view.frameOrigin = { (CGFloat)x, (CGFloat)y };
 }
 
 static std::pair<int, int> view_client_to_screen(::mforms::View *self, int x, int y)
@@ -843,7 +839,7 @@ static bool view_is_enabled(::mforms::View *self)
   return false;
 }
 
-static int view_get_width(::mforms::View *self)
+static int view_get_width(const mforms::View *self)
 {
   id view = self->get_data();
   if ( view )
@@ -855,51 +851,64 @@ static int view_get_width(::mforms::View *self)
   return 0;
 }
 
-static int view_get_height(::mforms::View *self)
+static int view_get_height(const mforms::View *self)
 {
-  id view = self->get_data();
-  if ( view )
+  id frontend = self->get_data();
+  if (frontend != nil)
   {
-    if ([view isKindOfClass: [NSWindow class]])
-      return NSHeight([view contentRectForFrameRect:[view frame]]);
-    return NSHeight([view frame]);
+    if ([frontend isKindOfClass: NSWindow.class])
+      return NSHeight([frontend contentRectForFrameRect: [frontend frame]]);
+    return NSHeight([frontend frame]);
   }
   return 0;
 }
 
 static int view_get_preferred_width(::mforms::View *self)
 {
-  id view = self->get_data();
-  if ( view )
+  id frontend = self->get_data();
+  if (frontend != nil)
   {
-    return [view preferredSize].width;
+    if ([frontend isKindOfClass: NSWindow.class])
+    {
+      NSSize size = [frontend preferredSize: [frontend frame].size];
+      return size.width;
+    }
+    return NSWidth([frontend frame]);
   }
   return 0;
 }
 
 static int view_get_preferred_height(::mforms::View *self)
 {
-  id view = self->get_data();
-  if ( view )
+  id frontend = self->get_data();
+  if (frontend != nil)
   {
-    return [view preferredSize].height;
+    if ([frontend isKindOfClass: NSWindow.class])
+    {
+      NSSize size = [frontend preferredSize: [frontend frame].size];
+      return size.height;
+    }
+    return NSHeight([frontend frame]);
   }
   return 0;
 }
 
-
-static void view_show(::mforms::View *self, bool show)
+static void view_show(mforms::View *self, bool show)
 {
-  id view = self->get_data();
-  
-  if ( view && [view isHidden] != !show)
-  {
-    [view setHidden:!show];
+  id frontend = self->get_data();
+  if ([frontend isKindOfClass: NSView.class]) {
+    NSView *view = frontend;
 
-    if ([view respondsToSelector: @selector(superview)])
-      [[view superview] subviewMinimumSizeChanged];
-    if (show && [view respondsToSelector:@selector(window)])
-      [[view window] recalculateKeyViewLoop];
+    if (view.isHidden != !show)
+    {
+      view.hidden = !show;
+      [view.superview relayout];
+      [view.window recalculateKeyViewLoop];
+    }
+  } else {
+    if ([frontend isKindOfClass: NSWindow.class]) {
+      [frontend orderFrontRegardless];
+    }
   }
 }
 
@@ -936,7 +945,7 @@ static void view_set_tooltip(::mforms::View *self, const std::string &text)
 static void view_set_font(::mforms::View *self, const std::string &fontDescription)
 {
   id view = self->get_data();
-  if (view && [view respondsToSelector: @selector(setFont)])
+  if (view && [view respondsToSelector: @selector(setFont:)])
   {
     std::string name;
     float size;
@@ -966,14 +975,8 @@ static void view_set_name(mforms::View *self, const std::string&)
 
 static void view_relayout(mforms::View *self)
 {
-  if ([[NSThread currentThread] isMainThread])
-    [self->get_data() subviewMinimumSizeChanged];
-  else
-  {
-    id view = self->get_data();
-    // this performSelector is cancelled in [MFContainerView dealloc]
-    [view performSelectorOnMainThread: @selector(subviewMinimumSizeChanged) withObject: view waitUntilDone: false];
-  }
+  id view = self->get_data();
+  [view performSelectorOnMainThread: @selector(relayout) withObject: nil waitUntilDone: true];
 }
 
 static void view_set_needs_repaint(mforms::View *self)
@@ -999,7 +1002,7 @@ static std::string view_get_front_color(::mforms::View *self)
 {
   if ([self->get_data() respondsToSelector: @selector(textColor)])
   {
-    return [[[self->get_data() textColor] hexString] UTF8String];
+    return [self->get_data() textColor].hexString.UTF8String;
   }
   return "";
 }
@@ -1022,7 +1025,7 @@ static std::string view_get_back_color(::mforms::View *self)
     if ([self->get_data() respondsToSelector: @selector(drawsBackground)]
        && ![self->get_data() drawsBackground])
       return "";
-    return [[[self->get_data() backgroundColor] hexString] UTF8String];
+    return [self->get_data() backgroundColor].hexString.UTF8String;
   }
   return "";
 }
@@ -1045,14 +1048,19 @@ static void view_set_padding(::mforms::View *self, int left, int top, int right,
 
 static void view_focus(::mforms::View *self)
 {
-  id view = self->get_data();
-  [[view window] makeFirstResponder: view];
+  id frontend = self->get_data();
+  if ([frontend isKindOfClass: NSView.class]) {
+    [[frontend window] makeKeyAndOrderFront: frontend];
+    [[frontend window] makeFirstResponder: frontend];
+  }
+  else
+    [frontend makeKeyAndOrderFront: frontend];
 }
 
 static bool view_has_focus(::mforms::View *self)
 {
   id view = self->get_data();
-  id firstResponder = [[view window] firstResponder];
+  id firstResponder = [view window].firstResponder;
   if (firstResponder == view)
     return true;
   if ([firstResponder respondsToSelector: @selector(delegate)] && [firstResponder delegate] == view)
@@ -1112,6 +1120,7 @@ void cf_view_init()
   f->_view_impl.get_preferred_width  = &view_get_preferred_width;
   f->_view_impl.get_preferred_height = &view_get_preferred_height;
   f->_view_impl.set_size             = &view_set_size;
+  f->_view_impl.set_min_size         = &view_set_min_size;
   f->_view_impl.set_padding          = &view_set_padding;
 
   f->_view_impl.get_x                = &view_get_x;
