@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2013, 2017, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,17 +17,13 @@
  * 02110-1301  USA
  */
 
-#ifndef _MFORMS_NATIVE_H_
-#define _MFORMS_NATIVE_H_
+#pragma once
 
 #include "mforms/view.h"
 
 namespace mforms {
-  class MFORMS_EXPORT NativeContainer : public View
-  {
+  class MFORMS_EXPORT NativeContainer : public View {
   public:
     NativeContainer();
   };
 };
-
-#endif
