@@ -1,4 +1,51 @@
-variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
+variable_groups = [ ('group_replication_group_name', ['Replication/Group']),
+  ('group_replication_start_on_boot', ['Replication/Group']),
+  ('group_replication_local_address', ['Replication/Group']),
+  ('group_replication_group_seeds', ['Replication/Group']),
+  ('group_replication_force_members', ['Replication/Group']),
+  ('group_replication_bootstrap_group', ['Replication/Group']),
+  ('group_replication_poll_spin_loops', ['Replication/Group']),
+  ('group_replication_recovery_retry_count', ['Replication/Group']),
+  ('group_replication_recovery_reconnect_interval', ['Replication/Group']),
+  ('group_replication_recovery_use_ssl', ['Replication/Group']),
+  ('group_replication_recovery_ssl_ca', ['Replication/Group']),
+  ('group_replication_recovery_ssl_capath', ['Replication/Group']),
+  ('group_replication_recovery_ssl_cert', ['Replication/Group']),
+  ('group_replication_recovery_ssl_key', ['Replication/Group']),
+  ('group_replication_recovery_ssl_crl', ['Replication/Group']),
+  ('group_replication_recovery_ssl_crlpath', ['Replication/Group']),
+  ('group_replication_recovery_ssl_verify_server_cert', ['Replication/Group']),
+  ('group_replication_recovery_complete_at', ['Replication/Group']),
+  ('group_replication_components_stop_timeout', ['Replication/Group']),
+  ('group_replication_allow_local_lower_version_join', ['Replication/Group']),
+  ('group_replication_allow_local_disjoint_gtids_join', ['Replication/Group']),
+  ('group_replication_auto_increment_increment', ['Replication/Group']),
+  ('group_replication_compression_threshold', ['Replication/Group']),
+  ('group_replication_gtid_assignment_block_size', ['Replication/Group']),
+  ('group_replication_ssl_mode', ['Replication/Group']),
+  ('group_replication_single_primary_mode', ['Replication/Group']),
+  ( 'group_replication_enforce_update_everywhere_checks',
+    ['Replication/Group']),
+  ('group_replication_flow_control_mode', ['Replication/Group']),
+  ( 'group_replication_flow_control_certifier_threshold',
+    ['Replication/Group']),
+  ('group_replication_flow_control_applier_threshold', ['Replication/Group']),
+  ('group_replication_ip_whitelist', ['Replication/Group']),
+  ('mysqlx_port', ['Other/X']),
+  ('mysqlx_max_connections', ['Other/X']),
+  ('mysqlx_min_worker_threads', ['Other/X']),
+  ('mysqlx_idle_worker_thread_timeout', ['Other/X']),
+  ('mysqlx_max_allowed_packet', ['Other/X']),
+  ('mysqlx_connect_timeout', ['Other/X']),
+  ('mysqlx_ssl', ['Other/X']),
+  ('mysqlx_ssl_key', ['Other/X']),
+  ('mysqlx_ssl_ca', ['Other/X']),
+  ('mysqlx_ssl_capath', ['Other/X']),
+  ('mysqlx_ssl_cert', ['Other/X']),
+  ('mysqlx_ssl_cipher', ['Other/X']),
+  ('mysqlx_ssl_crl', ['Other/X']),
+  ('mysqlx_ssl_crlpath', ['Other/X']),
+  ('abort-slave-event-count', ['Replication/Slave']),
   ('allow-suspicious-udfs', ['Security/Security']),
   ('ansi', ['General/SQL']),
   ('audit-log', ['Logging/Audit']),
@@ -14,9 +61,10 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('audit_log_strategy', ['Logging/Audit']),
   ('authentication_windows_log_level', ['Security/Security']),
   ('authentication_windows_use_principal_name', ['Security/Security']),
+  ('auto_generate_certs', ['Security/Security']),
   ('autocommit', ['General/Transactions']),
   ('avoid_temporal_upgrade', []),
-  ('backup_elevation', ['Security/Validate password']),
+  ('backup_elevation', ['General/Backup']),
   ('backup_history_log', ['General/Backup']),
   ('backup_history_log_file', ['General/Backup']),
   ('backup_progress_log', ['General/Backup']),
@@ -51,16 +99,20 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('collation-server', ['General/International']),
   ('completion_type', ['Advanced/Transactions']),
   ('concurrent_insert', ['MyISAM/General']),
+  ('connection_control_failed_connections_threshold', []),
+  ('connection_control_max_connection_delay', []),
+  ('connection_control_min_connection_delay', []),
   ('connect_timeout', ['Networking/Timeout Settings']),
   ('console', ['Logging/General']),
   ('core-file', ['General/System']),
+  ('create_old_temporals', []),
   ('daemon_memcached_enable_binlog', ['Other/Memcached']),
   ('daemon_memcached_engine_lib_name', ['Other/Memcached']),
   ('daemon_memcached_engine_lib_path', ['Other/Memcached']),
   ('daemon_memcached_option', ['Other/Memcached']),
   ('daemon_memcached_r_batch_size', ['Other/Memcached']),
   ('daemon_memcached_w_batch_size', ['Other/Memcached']),
-  ('daemonize', []),
+  ('daemonize', ['Advanced/General']),
   ('datadir', ['General/Directories']),
   ('debug', ['Advanced/General']),
   ('debug-sync-timeout', ['Advanced/General']),
@@ -79,9 +131,12 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('delayed_queue_size', ['Advanced/Insert delayed settings']),
   ('des-key-file', ['Security/Security']),
   ('disable_gtid_unsafe_statements', ['Replication/General']),
+  ('disable-partition-engine-check', []),
+  ('disabled_storage_engines', []),
   ('disconnect-slave-event-count', ['Replication/Slave']),
   ('disconnect_on_expired_password', ['Security/Authentication']),
   ('div_precision_increment', ['Advanced/General']),
+  ('early-plugin-load', ['Advanced/General']),
   ('enable-locking', ['General/Features']),
   ('enable-named-pipe', ['Networking/General']),
   ('enable-pstack', ['General/Features']),
@@ -109,19 +164,20 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('gtid-mode', ['Replication/General']),
   ('ignore-builtin-innodb', ['InnoDB/General']),
   ('ignore-db-dir', ['General/System']),
+  ('information_schema_stats', []),
   ('init-file', ['General/General']),
   ('init-rpl-role', ['Replication/General']),
   ('init_connect', ['Advanced/General']),
   ('init_slave', ['Advanced/General', 'Replication/Slave']),
-  ('initialize', []),
-  ('initialize-insecure', []),
+  ('initialize', ['Advanced/General']),
+  ('initialize-insecure', ['Advanced/General']),
   ('innodb-safe-binlog', ['InnoDB/General']),
   ('innodb-status-file', ['InnoDB/General']),
   ('innodb_adaptive_flushing', ['InnoDB/General']),
   ('innodb_adaptive_flushing_lwm', ['InnoDB/General']),
   ('innodb_adaptive_hash_index', ['InnoDB/General']),
+  ('innodb_adaptive_hash_index_parts', ['InnoDB/General']),
   ('innodb_adaptive_max_sleep_delay', ['InnoDB/General']),
-  ('innodb_additional_mem_pool_size', ['InnoDB/Memory']),
   ('innodb_api_bk_commit_interval', ['InnoDB/General']),
   ('innodb_api_disable_rowlock', ['InnoDB/General']),
   ('innodb_api_enable_binlog', ['InnoDB/General']),
@@ -129,8 +185,10 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('innodb_api_trx_level', ['InnoDB/General']),
   ('innodb_autoextend_increment', ['InnoDB/General']),
   ('innodb_autoinc_lock_mode', ['InnoDB/General']),
+  ('innodb_background_drop_list_empty', ['InnoDB/General']),
   ('innodb_buffer_pool_awe_mem_mb', ['InnoDB/Buffer pool']),
-  ('innodb_buffer_pool_chunk_size', []),
+  ('innodb_buffer_pool_chunk_size', ['InnoDB/Buffer pool']),
+  ('innodb_buffer_pool_debug', []),
   ('innodb_buffer_pool_dump_at_shutdown', ['InnoDB/Buffer pool']),
   ('innodb_buffer_pool_dump_now', ['InnoDB/Buffer pool']),
   ('innodb_buffer_pool_dump_pct', ['InnoDB/General']),
@@ -142,10 +200,12 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('innodb_buffer_pool_size', ['InnoDB/Buffer pool', 'InnoDB/Memory']),
   ('innodb_change_buffer_max_size', ['InnoDB/General']),
   ('innodb_change_buffering', ['InnoDB/General']),
+  ('innodb_change_buffering_debug', ['InnoDB/General']),
   ('innodb_checksum_algorithm', ['InnoDB/General']),
   ('innodb_checksums', ['InnoDB/General']),
   ('innodb_cmp_per_index_enabled', ['InnoDB/General']),
   ('innodb_commit_concurrency', ['InnoDB/General']),
+  ('innodb_compress_debug', ['InnoDB/General']),
   ('innodb_compression_failure_threshold_pct', ['InnoDB/General']),
   ('innodb_compression_level', ['InnoDB/General']),
   ('innodb_compression_pad_pct_max', ['InnoDB/General']),
@@ -153,10 +213,14 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('innodb_create_intrinsic', ['InnoDB/General']),
   ('innodb_data_file_path', ['InnoDB/Datafiles']),
   ('innodb_data_home_dir', ['InnoDB/Datafiles']),
+  ('innodb_deadlock_detect', []),
+  ('innodb_default_row_format', ['InnoDB/General']),
   ('innodb_disable_sort_file_cache', ['InnoDB/General']),
+  ('innodb_disable_resize_buffer_pool_debug', ['InnoDB/General']),
   ('innodb_doublewrite', ['InnoDB/General']),
   ('innodb_extra_dirty_writes', ['InnoDB/General']),
   ('innodb_fast_shutdown', ['InnoDB/Various']),
+  ('innodb_fil_make_page_dirty_debug', []),
   ('innodb_file_format', ['InnoDB/Datafiles']),
   ('innodb_file_format_check', ['InnoDB/Datafiles']),
   ('innodb_file_format_max', ['InnoDB/Datafiles']),
@@ -166,7 +230,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('innodb_flush_log_at_trx_commit', ['InnoDB/Logfiles']),
   ('innodb_flush_method', ['InnoDB/Logfiles']),
   ('innodb_flush_neighbors', ['InnoDB/Logfiles']),
-  ('innodb_flush_sync', []),
+  ('innodb_flush_sync', ['InnoDB/Logfiles']),
   ('innodb_flushing_avg_loops', ['InnoDB/General']),
   ('innodb_force_load_corrupted', ['InnoDB/General']),
   ('innodb_force_recovery', ['InnoDB/General']),
@@ -185,12 +249,14 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('innodb_io_capacity', ['InnoDB/General']),
   ('innodb_io_capacity_max', ['InnoDB/General']),
   ('innodb_large_prefix', ['InnoDB/General']),
+  ('innodb_limit_optimistic_insert_debug', ['InnoDB/General']),
   ('innodb_lock_wait_timeout', ['InnoDB/General']),
   ('innodb_locks_unsafe_for_binlog', ['InnoDB/General']),
   ('innodb_log_arch_dir', ['InnoDB/Logfiles']),
   ('innodb_log_archive', ['InnoDB/Logfiles']),
   ('innodb_log_buffer_size', ['InnoDB/Logfiles']),
-  ('innodb_log_checksum_algorithm', []),
+  ('innodb_log_checksum_algorithm', ['InnoDB/Logfiles']),
+  ('innodb_log_checksums', ['InnoDB/Logfiles']),
   ('innodb_log_compressed_pages', ['InnoDB/Logfiles']),
   ('innodb_log_file_size', ['InnoDB/Logfiles']),
   ('innodb_log_files_in_group', ['InnoDB/Logfiles']),
@@ -203,23 +269,26 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('innodb_max_purge_lag', ['InnoDB/General']),
   ('innodb_max_purge_lag_delay', ['InnoDB/General']),
   ('innodb_max_undo_log_size', ['InnoDB/General']),
+  ('innodb_additional_mem_pool_size', ['InnoDB/Memory']),
+  ('innodb_merge_threshold_set_all_debug', ['InnoDB/General']),
   ('innodb_mirrored_log_groups', ['InnoDB/Logfiles']),
   ('innodb_monitor_disable', ['InnoDB/General']),
   ('innodb_monitor_enable', ['InnoDB/General']),
   ('innodb_monitor_reset', ['InnoDB/General']),
   ('innodb_monitor_reset_all', ['InnoDB/General']),
+  ('innodb_numa_interleave', ['InnoDB/General']),
   ('innodb_old_blocks_pct', ['InnoDB/General']),
   ('innodb_old_blocks_time', ['InnoDB/General']),
   ('innodb_online_alter_log_max_size', ['InnoDB/General', 'InnoDB/Logfiles']),
   ('innodb_open_files', ['InnoDB/General']),
   ( 'innodb_optimize_fulltext_only',
     ['InnoDB/Fulltext search', 'InnoDB/General']),
-  ('innodb_optimize_point_storage', []),
+  ('innodb_optimize_point_storage', ['InnoDB/General']),
   ('innodb_page_cleaners', ['InnoDB/Memory']),
   ('innodb_page_size', ['InnoDB/Memory']),
   ('innodb_print_all_deadlocks', ['InnoDB/General']),
   ('innodb_purge_batch_size', ['InnoDB/General']),
-  ('innodb_purge_rseg_truncate_frequency', []),
+  ('innodb_purge_rseg_truncate_frequency', ['InnoDB/General']),
   ('innodb_purge_threads', ['InnoDB/General']),
   ('innodb_random_read_ahead', ['InnoDB/General']),
   ('innodb_read_ahead_threshold', ['InnoDB/General']),
@@ -228,9 +297,11 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('innodb_replication_delay', ['InnoDB/General']),
   ('innodb_rollback_on_timeout', ['InnoDB/General']),
   ('innodb_rollback_segments', ['InnoDB/General']),
+  ('innodb_saved_page_number_debug', ['InnoDB/General']),
   ('innodb_sort_buffer_size', ['InnoDB/General', 'InnoDB/Memory']),
   ('innodb_spin_wait_delay', ['InnoDB/General']),
   ('innodb_stats_auto_recalc', ['InnoDB/General']),
+  ('innodb_stats_include_delete_marked', ['InnoDB/General']),
   ('innodb_stats_method', ['InnoDB/General']),
   ('innodb_stats_on_metadata', ['InnoDB/General']),
   ('innodb_stats_persistent', ['InnoDB/General']),
@@ -243,13 +314,17 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('innodb_support_xa', ['InnoDB/General']),
   ('innodb_sync_array_size', ['InnoDB/General']),
   ('innodb_sync_spin_loops', ['InnoDB/General']),
+  ('innodb_sync_debug', ['InnoDB/General']),
   ('innodb_table_locks', ['InnoDB/General']),
   ('innodb_temp_data_file_path', ['InnoDB/General']),
+  ('innodb_tmpdir', ['InnoDB/General']),
   ('innodb_thread_concurrency', ['InnoDB/General']),
   ('innodb_thread_concurrency_timer_based', ['InnoDB/General']),
   ('innodb_thread_sleep_delay', ['InnoDB/General']),
+  ('innodb_trx_purge_view_update_only_debug', ['InnoDB/General']),
+  ('innodb_trx_rseg_n_slots_debug', ['InnoDB/General']),
   ('innodb_undo_directory', ['InnoDB/General', 'InnoDB/Logfiles']),
-  ('innodb_undo_log_truncate', []),
+  ('innodb_undo_log_truncate', ['InnoDB/General', 'InnoDB/Logfiles']),
   ('innodb_undo_logs', ['InnoDB/General', 'InnoDB/Logfiles']),
   ('innodb_undo_tablespaces', ['InnoDB/General']),
   ('innodb_use_legacy_cardinality_algorithm', ['InnoDB/General']),
@@ -257,7 +332,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('innodb_use_sys_malloc', ['InnoDB/General']),
   ('innodb_write_io_threads', ['InnoDB/General']),
   ('interactive_timeout', ['Networking/Timeout Settings']),
-  ('internal_tmp_disk_storage_engine', []),
+  ('internal_tmp_disk_storage_engine', ['InnoDB/General']),
   ('isam', ['General/Features']),
   ('join_buffer_size', ['General/Memory usage']),
   ('join_cache_level', ['General/Memory usage']),
@@ -266,6 +341,8 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('key_cache_age_threshold', ['MyISAM/General']),
   ('key_cache_block_size', ['Advanced/Various']),
   ('key_cache_division_limit', ['Advanced/Various']),
+  ('keyring_file_data', []),
+  ('keyring_okv_conf_dir', []),
   ('language', ['General/International']),
   ('large-pages', ['General/Memory usage']),
   ('lc-messages', ['General/International']),
@@ -290,8 +367,9 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('log-tc', ['Logging/Advanced log options']),
   ('log-tc-size', ['Logging/Advanced log options']),
   ('log-warnings', ['Logging/Advanced log options']),
-  ('log_backward_compatible_user_definitions', []),
+  ('log_backward_compatible_user_definitions', ['Logging/General']),
   ('log_bin_use_v1_row_events', ['Logging/Binlog Options']),
+  ('log_builtin_as_identified_by_password', ['Logging/General']),
   ('log_error_verbosity', ['Logging/General']),
   ('log_slave_updates', ['Logging/General']),
   ('log_syslog', ['Logging/General']),
@@ -327,19 +405,20 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('max_delayed_threads', ['Advanced/Insert delayed settings']),
   ('max_digest_length', ['Advanced/General']),
   ('max_error_count', ['Advanced/General']),
+  ('max_execution_time', ['Advanced/Various']),
   ('max_heap_table_size', ['Advanced/Various']),
   ('max_join_size', ['Advanced/Various']),
   ('max_length_for_sort_data', ['Advanced/Various']),
   ('max_long_data_size', ['General/General']),
+  ('max_points_in_geometry', ['Advanced/Various']),
   ('max_prepared_stmt_count', ['Advanced/General']),
   ('max_relay_log_size', ['Replication/Relay Log']),
   ('max_seeks_for_key', ['Advanced/Various']),
   ('max_sort_length', ['Advanced/Various']),
   ('max_sp_recursion_depth', ['Advanced/General']),
-  ('max_statement_time', ['General/General']),
   ('max_user_connections', ['Networking/Advanced']),
   ('max_write_lock_count', ['Advanced/Various']),
-  ('mecab_rc_file', []),
+  ('mecab_rc_file', ['InnoDB/Fulltext search']),
   ('memlock', ['Advanced/General']),
   ('min-examined-row-limit', ['Advanced/General']),
   ('multi_range_count', ['Advanced/Various']),
@@ -356,7 +435,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('myisam_stats_method', ['MyISAM/Advanced Settings']),
   ('myisam_use_mmap', ['MyISAM/Advanced Settings']),
   ('mysql-backup', ['General/Backup']),
-  ('mysql_native_password_proxy_users', []),
+  ('mysql_native_password_proxy_users', ['Security/Authentication']),
   ('mysql_firewall_max_query_size', ['General/Firewall']),
   ('mysql_firewall_mode', ['General/Firewall']),
   ('mysql_firewall_trace', ['General/Firewall']),
@@ -364,6 +443,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('ndb-blob-read-batch-bytes', ['Other/NDB']),
   ('ndb-blob-write-batch-bytes', ['Other/NDB']),
   ('ndb-cluster-connection-pool', ['Other/NDB']),
+  ('ndb-cluster-connection-pool-nodeids', ['Other/NDB']),
   ('ndb-connectstring', ['Other/NDB']),
   ('ndb-log-transaction-id', ['Other/NDB']),
   ('ndb-log-update-as-write', ['Other/NDB']),
@@ -373,24 +453,30 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('ndb-recv-thread-cpu-mask', ['Other/NDB']),
   ('ndb-wait-connected', ['Other/NDB']),
   ('ndb-wait-setup', ['Other/NDB']),
+  ('ndb-allow-copying-alter-table', ['Other/NDB']),
   ('ndb_autoincrement_prefetch_sz', ['Other/NDB']),
   ('ndb_cache_check_time', ['Other/NDB']),
+  ('ndb_data_node_neighbour', ['Other/NDB']),
+  ('ndb_default_column_format', ['Other/NDB']),
   ('ndb_deferred_constraints', ['Other/NDB']),
   ('ndb_distribution', ['Other/NDB']),
   ('ndb_eventbuffer_free_percent', ['Other/NDB']),
   ('ndb_eventbuffer_max_alloc', ['Other/NDB']),
   ('ndb_extra_logging', ['Other/NDB']),
   ('ndb_force_send', ['Other/NDB']),
+  ('ndb_fully_replicated', ['Other/NDB']),
   ('ndb_index_stat_cache_entries', ['Other/NDB']),
   ('ndb_index_stat_enable', ['Other/NDB']),
   ('ndb_index_stat_option', ['Other/NDB']),
   ('ndb_index_stat_update_freq', ['Other/NDB']),
   ('ndb_log_apply_status', ['Other/NDB']),
   ('ndb_log_empty_epochs', ['Other/NDB']),
+  ('ndb_log_empty_update', ['Other/NDB']),
   ('ndb_log_exclusive_reads', ['Other/NDB']),
   ('ndb_log_orig', ['Other/NDB']),
   ('ndb_log_updated_only', ['Other/NDB']),
   ('ndb_optimized_node_selection', ['Other/NDB']),
+  ('ndb_read_backup', ['Other/NDB']),
   ('ndb_report_thresh_binlog_epoch_slip', ['Other/NDB']),
   ('ndb_report_thresh_binlog_mem_usage', ['Other/NDB']),
   ('ndb_show_foreign_key_mock_tables', ['Other/NDB']),
@@ -402,19 +488,19 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('net_retry_count', ['Networking/Advanced']),
   ('net_write_timeout', ['Networking/Timeout Settings']),
   ('new', ['Advanced/Various']),
-  ('ngram_token_size', []),
-  ('offline_mode', []),
+  ('ngram_token_size', ['InnoDB/Fulltext search']),
+  ('offline_mode', ['General/System']),
   ('old', ['General/General']),
   ('old-alter-table', ['Advanced/Deprecated']),
   ('old-protocol', ['Advanced/Deprecated']),
   ('old-style-user-limits', ['Advanced/General']),
-  ('old_passwords', ['Security/Authentication']),
   ('one-thread', ['General/General']),
   ('open-files-limit', ['Advanced/General']),
   ('optimizer_join_cache_level', ['Performance/Optimizer']),
   ('optimizer_prune_level', ['Performance/Optimizer']),
   ('optimizer_search_depth', ['Performance/Optimizer']),
   ('optimizer_switch', ['Performance/Optimizer']),
+  ('parser_max_mem_size', ['General/SQL']),
   ('partition', []),
   ( 'performance-schema-consumer-events-stages-current',
     ['Performance/Performance Schema']),
@@ -450,6 +536,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('performance_schema', ['Performance/Performance Schema']),
   ('performance_schema_accounts_size', ['Performance/Performance Schema']),
   ('performance_schema_digests_size', ['Performance/Performance Schema']),
+  ('performance_schema_error_size', ['Performance/Performance Schema']),
   ( 'performance_schema_events_stages_history_long_size',
     ['Performance/Performance Schema']),
   ( 'performance_schema_events_stages_history_size',
@@ -470,6 +557,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('performance_schema_max_cond_classes', ['Performance/Performance Schema']),
   ( 'performance_schema_max_cond_instances',
     ['Performance/Performance Schema']),
+  ('performance_schema_max_digest_length', ['Performance/Performance Schema']),
   ('performance_schema_max_file_classes', ['Performance/Performance Schema']),
   ('performance_schema_max_file_handles', ['Performance/Performance Schema']),
   ( 'performance_schema_max_file_instances',
@@ -516,6 +604,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ( 'performance_schema_setup_objects_size',
     ['Performance/Performance Schema']),
   ('performance_schema_users_size', ['Performance/Performance Schema']),
+  ('persisted_globals_load', ['General/System']),
   ('pid-file', ['General/System']),
   ('plugin', ['General/Features']),
   ('plugin-load', ['General/Features']),
@@ -533,6 +622,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('query_cache_wlock_invalidate', ['Performance/Query cache']),
   ('query_prealloc_size', ['Advanced/Various']),
   ('range_alloc_block_size', ['Advanced/Various']),
+  ('range_optimizer_max_mem_size', ['Advanced/Various']),
   ('read_buffer_size', ['Advanced/Various']),
   ('read_only', ['Security/Security']),
   ('read_rnd_buffer_size', ['Advanced/Various']),
@@ -555,6 +645,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('report-password', ['Replication/General']),
   ('report-port', ['Replication/General']),
   ('report-user', ['Replication/General']),
+  ('require_secure_transport', ['Security/Security']),
   ('restore_disables_events', ['Advanced/General']),
   ('restore_elevation', ['Advanced/General']),
   ('restore_precheck', ['Advanced/General']),
@@ -563,6 +654,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('safe-show-database', ['Security/Security']),
   ('safe-user-create', ['Security/Security']),
   ('safemalloc-mem-limit', ['Security/Security']),
+  ('schema_definition_cache', ['Security/Security']),
   ('secure-auth', ['Security/Security']),
   ('secure-backup-file-priv', ['Security/Security']),
   ('secure-file-priv', ['Security/Security']),
@@ -573,8 +665,10 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('session_track_state_change', ['General/General']),
   ('session_track_system_variables', ['General/General']),
   ('set-variable', ['Advanced/Deprecated']),
+  ('sha256_password_auto_generate_rsa_keys', []),
   ('sha256_password_proxy_users', []),
   ('shared_memory', []),
+  ('shared_memory_base_name', []),
   ('show-slave-auth-info', ['Replication/Slave']),
   ('show_compatibility_56', []),
   ('show_old_temporals', []),
@@ -632,7 +726,9 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('ssl-key', ['Networking/SSL']),
   ('standalone', ['Advanced/General']),
   ('stored_program_cache', ['General/General']),
+  ('stored_program_definition_cache', []),
   ('super-large-pages', ['General/General']),
+  ('super_read_only', []),
   ('symbolic-links', ['General/System']),
   ('sync_binlog', ['Logging/Binlog Options']),
   ('sync_frm', ['Advanced/General']),
@@ -640,6 +736,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('sync_relay_log', ['Replication/Relay Log']),
   ('sync_relay_log_info', ['Replication/Relay Log']),
   ('sysdate-is-now', ['General/System']),
+  ('tablespace_definition_cache', []),
   ('table_cache', []),
   ('table_lock_wait_timeout', []),
   ('tc-heuristic-recover', []),
@@ -656,6 +753,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('thread_pool_stall_limit', ['Advanced/Thread specific settings']),
   ('thread_stack', ['Advanced/Thread specific settings']),
   ('timed_mutexes', ['InnoDB/General']),
+  ('tls_version', []),
   ('tmp_table_size', ['Advanced/Various']),
   ('tmpdir', ['General/Directories']),
   ('transaction-isolation', ['Advanced/Transactions']),
@@ -666,13 +764,10 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('use-symbolic-links', ['General/System']),
   ('user', ['General/System']),
   ('validate-password', []),
-  ('validate_password_dictionary_file', ['Security/Validate password']),
-  ('validate_password_length', ['Security/Validate password']),
-  ('validate_password_mixed_case_count', ['Security/Validate password']),
-  ('validate_password_number_count', ['Security/Validate password']),
-  ('validate_password_policy', ['Security/Validate password']),
-  ('validate_password_special_char_count', ['Security/Validate password']),
+  ('validate_password_check_user_name', []),
   ('verbose', []),
+  ('version_tokens_session', []),
+  ('version_tokens_session_number', []),
   ('wait_timeout', ['Networking/Timeout Settings']),
   ('warnings', ['Advanced/Deprecated']),
   ('skip-innodb', ['InnoDB/General'])]
