@@ -1,4 +1,4 @@
-# Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2016, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -22,9 +22,9 @@ import mforms
 import grt
 import threading
 
-import sys, os, csv
+import os
 
-from mforms import newTreeNodeView
+from mforms import newTreeView
 from mforms import FileChooser
 from sqlide_power_import_export_be import create_module
 from workbench.ui import WizardForm, WizardPage, WizardProgressPage
@@ -32,7 +32,7 @@ from datetime import datetime
 import operator
 
 
-from workbench.log import log_debug3, log_debug2, log_error
+from workbench.log import log_error
 
 last_location = None
 
@@ -90,7 +90,7 @@ class SimpleTabExport(mforms.Box):
         colbox.set_spacing(8)
         colbox.add(mforms.newLabel("Select columns you'd like to export"), False, True)
         
-        self.column_list = newTreeNodeView(mforms.TreeFlatList)
+        self.column_list = newTreeView(mforms.TreeFlatList)
         self.column_list.add_column(mforms.CheckColumnType, "Export", 50, True)
         self.column_list.add_column(mforms.StringColumnType, "Column name", self.owner.main.get_width(), False)
         self.column_list.end_columns()
@@ -153,13 +153,18 @@ class SimpleTabExport(mforms.Box):
         self.column_list.thaw_refresh()
         
     def get_query(self):
+        selected_columns = []
+        for i in range(self.column_list.count()):
+            if self.column_list.node_at_row(i).get_bool(0):
+                selected_columns.append(self.column_list.node_at_row(i).get_string(1))
+
         limit = ""
         if self.limit_entry.get_string_value():
             limit = "LIMIT %d" % int(self.limit_entry.get_string_value())
             if self.offset_entry.get_string_value():
                 limit = "LIMIT %d,%d" % (int(self.offset_entry.get_string_value()), int(self.limit_entry.get_string_value()))
         table_w_prefix = "%s.%s" % (self.owner.main.source_table['schema'], self.owner.main.source_table['table'])
-        return """SELECT %s FROM %s %s""" % (",".join([value['name'] for value in self.columns]), table_w_prefix, limit)
+        return """SELECT %s FROM %s %s""" % (",".join(selected_columns), table_w_prefix, limit)
         
 class AdvancedTabExport(mforms.Box):
     def __init__(self, editor, owner):
@@ -273,7 +278,7 @@ class ExportProgressPage(WizardProgressPage):
                 
     def on_close(self):
         if self.module and self.module.is_running:
-            if mforms.ResultOk == mforms.Utilities.show_message("Confirmation", "Do you wish to stop export process?", "Yes", "No", ""):
+            if mforms.ResultOk == mforms.Utilities.show_message("Confirmation", "Do you wish to stop the export process?", "Yes", "No", ""):
                 self.stop.set()
                 return True
             return False
@@ -300,7 +305,7 @@ class SelectFilePage(WizardPage):
         self.suspend_layout()
         self.set_spacing(16)
         
-        label = mforms.newLabel("Table Data Export allows you to easily export data into csv, json datafiles.\n")
+        label = mforms.newLabel("Table Data Export allows you to easily export data into CSV, JSON datafiles.\n")
         label.set_style(mforms.BoldInfoCaptionStyle)
 
         self.content.add(label, False, False)
@@ -331,9 +336,9 @@ class SelectFilePage(WizardPage):
             fradio.set_text(format.title)
             fradio.set_active(bool(self.active_module and self.active_module.name == format.name))
             fradio.add_clicked_callback(lambda f = format: self.output_type_changed(f))
-            radio_box.add(fradio, False, False)
+            radio_box.add(fradio, False, True)
             self.radio_opts.append({'radio':fradio, 'name': format.name})
-        self.content.add(radio_box, False, False)
+        self.content.add(radio_box, False, True)
 
         self.optpanel = mforms.newPanel(mforms.TitledBoxPanel)
         self.optpanel.set_title("Options:")
@@ -346,7 +351,7 @@ class SelectFilePage(WizardPage):
         self.export_local_cb.set_text("Export to local machine")
         self.export_local_cb.set_active(True)
         self.export_local_box.add(self.export_local_cb, False, True)
-        l = mforms.newLabel("""If checked rows will be exported on the location that started Workbench.\nIf not checked, rows will be exported on the server.\nIf server and computer that started Workbench are different machines, import of that file can be done manual way only.""")
+        l = mforms.newLabel("""If checked, rows will be exported on the location that started Workbench.\nIf not checked, rows will be exported on the server.\nIf server and computer that started Workbench are different machines, import of that file can be done manual way only.""")
         l.set_style(mforms.SmallHelpTextStyle)
         self.export_local_box.add(l, False, True)
         
@@ -373,7 +378,7 @@ class SelectFilePage(WizardPage):
         
     def validate(self):
         if not self.check_is_supported_format():
-            mforms.Utilities.show_error(self.main.title, "This file format is not supported, please select csv or json.", "Ok", "", "")
+            mforms.Utilities.show_error(self.main.title, "This file format is not supported, please select CSV or JSON.", "Ok", "", "")
             return False            
         file_path = self.exportfile_path.get_string_value()
         if not os.path.isdir(os.path.dirname(file_path)):
@@ -381,11 +386,11 @@ class SelectFilePage(WizardPage):
             return False
         if self.confirm_file_overwrite and os.path.isfile(file_path):
             self.destination_file_checked = True
-            if mforms.Utilities.show_warning(self.main.title, "The output file already exists, do you want to overwrite it?", "Yes", "No", "") != mforms.ResultOk:
+            if mforms.Utilities.show_warning(self.main.title, "The output file already exists. Do you want to overwrite it?", "Yes", "No", "") != mforms.ResultOk:
                 return False
             self.confirm_file_overwrite = False
         if self.main.data_input_page._showing_simple and not self.export_local_cb.get_active():
-           if mforms.Utilities.show_warning(self.main.title, "You've specified to export file on the server. Export may fail if the file already exists, please remove the file manually before continuing.", "Continue", "Cancel", "") != mforms.ResultOk:
+           if mforms.Utilities.show_warning(self.main.title, "You've specified to export file on the server. Export may fail if the file already exists. Please remove the file manually before continuing.", "Continue", "Cancel", "") != mforms.ResultOk:
                return False
         elif not self.destination_file_checked and os.path.isfile(file_path):
             self.destination_file_checked = True
@@ -412,7 +417,7 @@ class SelectFilePage(WizardPage):
             self.unsupported_output_format = True
             self.active_module = self.main.formats[0] # we use first format as default one
             if not silent:
-                mforms.Utilities.show_error(self.main.title, "This file format is not supported, please select csv or json.", "Ok", "", "")
+                mforms.Utilities.show_error(self.main.title, "This file format is not supported. Please select CSV or JSON.", "Ok", "", "")
     
     def load_module_options(self):
         self.suspend_layout()
@@ -429,7 +434,7 @@ class SelectFilePage(WizardPage):
                     operator.setitem(output, 'value', txt)
                 else:
                     field.set_value("")
-                    mforms.Utilities.show_error(self.main.title, "Due to the nature of this wizard, you can't use unicode characters in this place, as also only one character is allowed.","Ok","","")
+                    mforms.Utilities.show_error(self.main.title, "Due to the nature of this wizard, you can't use unicode characters in this place, as only one character is allowed.","Ok","","")
                     
 
             def set_selector_entry(selector, output):
@@ -441,21 +446,21 @@ class SelectFilePage(WizardPage):
             for name, opts in self.active_module.options.iteritems():
                 label_box = mforms.newBox(True)
                 label_box.set_spacing(8)
-                label_box.add(mforms.newLabel(opts['description']), False, False)
+                label_box.add(mforms.newLabel(opts['description']), False, True)
                 if opts['type'] == 'text':
                     opt_val = mforms.newTextEntry()
                     opt_val.set_size(35, -1)
                     opt_val.set_value(opts['value'])
                     opt_val.add_changed_callback(lambda field = opt_val, output = opts: set_text_entry(field, output))
-                    label_box.add_end(opt_val, False, False)
+                    label_box.add_end(opt_val, False, True)
                 if opts['type'] == 'select':
                     opt_val = mforms.newSelector()
                     opt_val.set_size(75, -1)
                     opt_val.add_items([v for v in opts['opts']])
                     opt_val.set_selected(opts['opts'].values().index(opts['value']))
                     opt_val.add_changed_callback(lambda selector = opt_val, output = opts: set_selector_entry(selector, output))
-                    label_box.add_end(opt_val, False, False)
-                self.optbox.add(label_box, False, False)
+                    label_box.add_end(opt_val, False, True)
+                self.optbox.add(label_box, False, True)
             self.optpanel.add(self.optbox)
             self.optpanel.show(True)        
         self.resume_layout()
@@ -471,7 +476,7 @@ class SelectFilePage(WizardPage):
         for module in self.main.formats:
             extensions.append(module.get_file_extension()[0])
  
-        filechooser.set_extensions("|".join(extensions), self.main.formats[0].get_file_extension()[1], False)
+        filechooser.set_extensions("|".join(extensions), self.active_module.get_file_extension()[1], False)
         
         if filechooser.run_modal():
             file_path = filechooser.get_path()
@@ -499,12 +504,15 @@ class DataInputPage(WizardPage):
         self.suspend_layout()
         self.set_spacing(16)
         
+        headingBox = mforms.newBox(True)
+        headingBox.set_spacing(16)
+        
         self.simple_export_box = mforms.newBox(False)
         self.simple_export_box.set_spacing(16)
         
-        label = mforms.newLabel("Select source table for export.")
+        label = mforms.newLabel("Select source table for export:")
         label.set_style(mforms.BoldInfoCaptionStyle)
-        self.simple_export_box.add(label, False, True)
+        headingBox.add(label, False, True)
         
         self.source_table_sel = mforms.newSelector()
         self.source_table_sel.set_size(self.get_width(), -1)
@@ -516,7 +524,9 @@ class DataInputPage(WizardPage):
         if table_name in self.table_list.keys():
             self.source_table_sel.set_selected(sorted_keys.index(table_name))
         self.source_table_sel.add_changed_callback(lambda selector = self.source_table_sel: self.source_table_changed(selector.get_string_value()))
-        self.simple_export_box.add(self.source_table_sel, False, True)
+        headingBox.add(self.source_table_sel, False, True)
+        
+        self.simple_export_box.add(headingBox, False, True)
         
         self.simple_export = SimpleTabExport(self.main.editor, self)
         self.simple_export_box.add(self.simple_export, True, True)
@@ -541,13 +551,16 @@ class DataInputPage(WizardPage):
         if rset:
             ok = rset.goToFirstRow()
             while ok:
-                col = {'name': None, 'type': None, 'is_string': None, 'is_number': None, 'is_date_or_time': None, 'is_bin': None, 'value': None}
+                col = {'name': None, 'type': None, 'is_string': None, 'is_geometry':None, 'is_bignumber':None, 'is_number': None, 'is_date_or_time': None, 'is_bin': None, 'value': None}
                 col['name'] = rset.stringFieldValueByName("Field")
                 col['type'] = rset.stringFieldValueByName("Type")
                 col['is_number'] = any(x in col['type'] for x in ['int', 'integer'])
+                col['is_geometry'] = any(x in col['type'] for x in ['geometry','geometrycollection', 'linestring', 'multilinestring', 'multipoint', 'multipolygon', 'point' , 'polygon'])
+                col['is_bignumber'] = any(x in col['type'] for x in ['bigint'])
                 col['is_float'] = any(x in col['type'] for x in ['decimal', 'float', 'double'])  
-                col['is_string'] = any(x in col['type'] for x in ['char', 'text', 'set', 'enum'])
-                col['is_bin'] = any(x in col['type'] for x in ['blob', 'binary'])              
+                col['is_string'] = any(x in col['type'] for x in ['char', 'text', 'set', 'enum', 'json'])
+                col['is_bin'] = any(x in col['type'] for x in ['blob', 'binary'])  
+                col['is_date_or_time'] = any(x in col['type'] for x in ['timestamp', 'datetime', 'date', 'time'])
                 cols.append(col)
                 ok = rset.nextRow()
         return cols
@@ -611,7 +624,7 @@ class DataInputPage(WizardPage):
     
     def validate(self):
         if len(self.get_columns()) == 0:
-            mforms.Utilities.show_message("Table Data Export", "You need to specify at least one column", "Ok", "","")
+            mforms.Utilities.show_message(self.main.title, "You need to specify at least one column", "Ok", "","")
             return False
         return True
 
